@@ -219,7 +219,7 @@ impl GeneralReadout for WindowsGeneralReadout {
         Ok(str)
     }
 
-    fn local_ip(&self, interface: String) -> Result<String, ReadoutError> {
+    fn local_ip(&self, interface: Option<String>) -> Result<String, ReadoutError> {
         crate::shared::local_ip(interface)
     }
 
